<?php

/**
  * PrestapressCategory class, PrestapressCategory.php
  * Prestapress module
  * @category classes
  *
  * @author AppSide
  * @copyright AppSide
  *
  */

class PspressCategory extends ObjectModel
{
	public $name;
	public $content;
	public $link_rewrite;
	public $meta_keywords;
	public $meta_description;
	
	public $active = 1;
	public $position;
	
	//protected	$fieldsRequiredLang = array('name');
	protected	$fieldsSizeLang = array('name' => 255,'link_rewrite' => 128);
	protected	$fieldsValidateLang = array('name' => 'isGenericName',
											'content' => 'isCleanHTML',
											'link_rewrite' => 'isLinkRewrite',
											'meta_description' => 'isGenericName',
										    'meta_keywords' => 'isGenericName');
	
	protected 	$table = 'press_category';
	protected 	$identifier = 'id_press_category';
	
	public function getFields()
	{
		return array('id_press_category' => $this->id,
					 'active' => (int)($this->active),
					 'position' => (int)($this->position));
	}
	
	public function getTranslationsFieldsChild()
	{
		parent::validateFieldsLang();
		return parent::getTranslationsFields(array('name','content','link_rewrite','meta_description','meta_keywords'));
	}
	
	public static function listCategories($id_lang = _PS_LANG_DEFAULT_, $active = true, $checkEmpty = false)
	{
		$query = 'SELECT c.id_press_category, cl.`name`, cl.link_rewrite
					FROM  '._DB_PREFIX_.'press_category c
					JOIN '._DB_PREFIX_.'press_category_lang cl ON (c.id_press_category  = cl.id_press_category)
					WHERE cl.id_lang = '.intval($id_lang);
		
		if($checkEmpty) $query .= ' AND cl.`name` != ""';
		
		if($active) $query .= ' AND c.active = 1';
			 
		$query .= ' ORDER BY c.position ASC, cl.`name` ASC';
		
		$result = Db::getInstance()->ExecuteS($query);
		
		return $result;
	}
	
	public function getPublications($id_lang = _PS_LANG_DEFAULT_, $publish = false, $start = 0, $limit = 5, $checkEmpty = false){
		
		$query = 'SELECT p.id_press_publication, pl.title, pl.excerpt, pl.link_rewrite, p.date_on, pi.id_press_image as default_img, pi.type as default_img_type
				  FROM  '._DB_PREFIX_.'press_publication p
				  JOIN '._DB_PREFIX_.'press_publication_lang pl ON (p.id_press_publication = pl.id_press_publication)
				  INNER JOIN '._DB_PREFIX_.'press_categories pc ON pc.id_press_publication = p.id_press_publication AND pc.id_press_category = '.$this->id.'
				  LEFT JOIN '._DB_PREFIX_.'press_image pi ON p.id_press_publication = pi.id_press_publication AND pi.default = 1 
				  WHERE pl.id_lang = '.intval($id_lang);
		
		if($checkEmpty) $query .= ' AND pl.`title` != ""';
		
		if($publish) $query .= ' AND p.status = "published" AND p.date_on <= NOW()';
		
		$query .= ' ORDER BY p.date_on DESC, p.id_press_publication DESC LIMIT '.$start.','.$limit;
		
		$result = Db::getInstance()->ExecuteS($query);
		
		return $result;
	}	
	
	public static function nbCategories()
	{			
		$result = Db::getInstance()->getRow('SELECT COUNT(c.id_press_category) as nb 
											 FROM '._DB_PREFIX_.'press_category c');
		if($result)
			return $result['nb'];
		return null;
	}
	
	public static function getPublicationCategories($id_lang = null, $publication_id, $checkEmpty = false)
	{
		if(empty($id_lang))
			$id_lang = (int)Configuration::get('PS_LANG_DEFAULT');
			
		$result = Db::getInstance()->ExecuteS('SELECT pc.`id_press_category`, cl.`name`, cl.`link_rewrite` 
												FROM '._DB_PREFIX_.'press_categories pc 
												INNER JOIN '._DB_PREFIX_.'press_category c ON c.`id_press_category` = pc.`id_press_category` AND c.`active` = 1 
												LEFT JOIN '._DB_PREFIX_.'press_category_lang cl ON cl.`id_press_category` = pc.`id_press_category` AND cl.`id_lang` = '.$id_lang.'
												WHERE pc.`id_press_publication` = '.(int) $publication_id.
												($checkEmpty == true ? ' AND cl.`name` != ""' : '' ).'
												ORDER BY c.`position` ASC, cl.`name` ASC');
		return $result;
	}
	
	public function nbPublications($id_lang = _PS_LANG_DEFAULT_,$publish = false, $checkEmpty = false)
	{
		$query = 'SELECT count(p.id_press_publication) as nb
				  FROM  '._DB_PREFIX_.'press_publication p
				  JOIN '._DB_PREFIX_.'press_publication_lang pl ON (p.id_press_publication = pl.id_press_publication)
				  INNER JOIN '._DB_PREFIX_.'press_categories pc ON pc.id_press_publication = p.id_press_publication AND pc.id_press_category = '.$this->id.'
				  WHERE pl.id_lang = '.intval($id_lang);
		
		if($checkEmpty) $query .= ' AND pl.`title` != ""';		  
	    if($publish) $query .= ' AND p.status = "published" AND p.date_on <= NOW()';
		 
		$result = Db::getInstance()->getRow($query);
		
		if($result)
			return $result['nb'];
		return null;
	}
	
	public static function getCategoryLink($category_id, $category_rewrite,$p = null){
		global $cookie;
		
		$rewrite_conf = Prestapress::getRewriteConf();
		
		if($rewrite_conf == true && Configuration::get('PS_REWRITING_SETTINGS')){
			
			$iso = '';
			$countLang = method_exists('Language','countActiveLanguages') ? Language::countActiveLanguages() : count(Language::getLanguages(true));
			
			if($countLang > 1){
				$iso = Language::getIsoById(intval($cookie->id_lang)).'/';
			}
			
			return _PS_BASE_URL_.__PS_BASE_URI__.$iso.'articles/'.$category_id.'-'.$category_rewrite.(!is_null($p) ? '?p='.$p : '');
		}else{
			return _PS_BASE_URL_.__PS_BASE_URI__.'modules/prestapress/content.php?category='.$category_id.(!is_null($p) ? '?p='.$p : '');
		}
		
	}
}

?>
