<?php

/**
  * PspressPublication class, PspressPublication.php
  * Prestapress module
  * @category classes
  *
  * @author AppSide
  * @copyright AppSide
  *
  */

class PspressPublication extends ObjectModel
{
	public $title;
	public $content;
	public $link_rewrite;
	public $excerpt;
	public $meta_description;
	public $meta_keywords;
	
	public $status;
	public $date_on;
	public $default_img;

 	//protected $fieldsRequiredLang = array('title');
	protected $fieldsSizeLang = array('title' => 255, 'content' => 65536, 'excerpt' => 65536, 'link_rewrite' => 128, 'meta_keywords' => 255, 'meta_description' => 255);
	protected $fieldsValidateLang = array('title' => 'isGenericName',
										  'content' => 'isCleanHTML',
										  'excerpt' => 'isCleanHTML',
										  'link_rewrite' => 'isLinkRewrite',
										  'meta_description' => 'isGenericName',
										  'meta_keywords' => 'isGenericName');
	
	protected $fieldsRequired = array('status');
	protected $fieldsValidate = array('status' => 'isGenericName', 'date_on' => 'isDate');
	protected $fieldsSize = array('status' => 20);
	
	protected $table = 'press_publication';
	protected $identifier = 'id_press_publication';
	
	public function __construct($id = NULL, $id_lang = NULL)
	{		
		parent::__construct($id, $id_lang);
		if($this->id){
			$this->default_img = $this->getDefaultImage();
		}
	}
	
	public function getFields() { 
		parent::validateFields();
		if (isset($this->id))
			$fields['id_press_publication'] = intval($this->id);
		$fields['status'] = $this->status;
		$fields['date_on'] = pSQL($this->date_on);
		return $fields; 
	}
	
	public function getTranslationsFieldsChild()
	{
		parent::validateFieldsLang();
		
		$fieldsArray = array('title','link_rewrite','excerpt','meta_description','meta_keywords');
		$fields = array();
		$languages = Language::getLanguages(false); 
		$defaultLanguage = Configuration::get('PS_LANG_DEFAULT');
		foreach ($languages as $language)
		{
			$fields[$language['id_lang']]['id_lang'] = $language['id_lang'];
			$fields[$language['id_lang']][$this->identifier] = intval($this->id);
			$fields[$language['id_lang']]['content'] = (isset($this->content[$language['id_lang']])) ? Tools::htmlentitiesDecodeUTF8(pSQL($this->content[$language['id_lang']], true)) : '';
			foreach ($fieldsArray as $field)
			{
				if (!Validate::isTableOrIdentifier($field))
					die(Tools::displayError());
				if (isset($this->{$field}[$language['id_lang']]) AND !empty($this->{$field}[$language['id_lang']]))
					$fields[$language['id_lang']][$field] = pSQL($this->{$field}[$language['id_lang']]);
				elseif (in_array($field, $this->fieldsRequiredLang))
					$fields[$language['id_lang']][$field] = pSQL($this->{$field}[$defaultLanguage]);
				else
					$fields[$language['id_lang']][$field] = '';
			}
		}
		return $fields;
	}
	
	public function add($autodate = true, $nullValues = false) { return parent::add($autodate, true); }
	
	public function update($nullValues = false)
	{
		parent::update();
	 	$result = 1;
	 	$fields = $this->getTranslationsFieldsChild();
		foreach ($fields as $field)
		{
			foreach ($field as $key => $value)
			 	if (!Validate::isTableOrIdentifier($key))
	 				die(Tools::displayError());
			$mode = Db::getInstance()->getRow('SELECT `id_lang` FROM `'.pSQL(_DB_PREFIX_.$this->table).'_lang` WHERE `'.pSQL($this->identifier).
			'` = '.intval($this->id).' AND `id_lang` = '.intval($field['id_lang']));
			$result *= (!Db::getInstance()->NumRows()) ? Db::getInstance()->AutoExecute(_DB_PREFIX_.$this->table.'_lang', $field, 'INSERT') : 
			Db::getInstance()->AutoExecute(_DB_PREFIX_.$this->table.'_lang', $field, 'UPDATE', '`'.
			pSQL($this->identifier).'` = '.intval($this->id).' AND `id_lang` = '.intval($field['id_lang']));
		}
		return $result;
	}
	
	public static function findPrestapress($search_query, $id_lang = _PS_LANG_DEFAULT_, $publish = false, $count = false, $start = 0, $limit = 5, $category_id = null, $checkEmpty = true){
		
		if($count){
			$select = 'COUNT(p.id_press_publication) as nb';
		}else{
			$select = 'p.id_press_publication, pl.title, pl.excerpt, pl.link_rewrite, pl.meta_description, 
						  p.date_on, pi.id_press_image as default_img, pi.type as default_img_type';
		}
		
		$query = 'SELECT '.$select.' FROM  '._DB_PREFIX_.'press_publication p
				  JOIN '._DB_PREFIX_.'press_publication_lang pl ON (p.id_press_publication = pl.id_press_publication)';
		
		if(!$count){
			$query .= ' LEFT JOIN '._DB_PREFIX_.'press_image pi ON p.id_press_publication = pi.id_press_publication AND pi.default = 1 '; 
		}
				  		
		if(!is_null($category_id))
			$query .= ' INNER JOIN '._DB_PREFIX_.'press_categories pc ON pc.id_press_publication = p.id_press_publication AND pc.id_press_category = '.$category_id;

		$query .= ' WHERE pl.id_lang = '.intval($id_lang);
		
		if($publish) $query .= ' AND p.status = "published" AND NOW() >= p.date_on';
		if($checkEmpty) $query .= ' AND pl.`title` != ""';
		
		$query .= ' AND ( pl.title LIKE \'%'.pSQL($search_query).'%\' 
							OR pl.excerpt LIKE \'%'.pSQL($search_query).'%\' 
							OR pl.meta_keywords LIKE \'%'.pSQL($search_query).'%\' )';
		
		if($count){
			$result = Db::getInstance()->getRow($query);
			return $result['nb'];
		}else{
			$query .= ' ORDER BY p.date_on DESC, p.id_press_publication DESC ';
			if(!is_null($limit) && !$count) $query .= ' LIMIT '.$start.','.$limit;
			return Db::getInstance()->ExecuteS($query);
		}
	}

	public static function listPrestapress($id_lang = _PS_LANG_DEFAULT_, $publish = false, $start = 0, $limit = 5, $category_id = null, $product_id = null, $except_id = null, $checkEmpty = false)
	{
		$query = 'SELECT p.id_press_publication, pl.title, pl.excerpt, pl.link_rewrite, pl.meta_description, 
						 p.date_on, pi.id_press_image as default_img, pi.type as default_img_type
				  FROM  '._DB_PREFIX_.'press_publication p
				  JOIN '._DB_PREFIX_.'press_publication_lang pl ON (p.id_press_publication = pl.id_press_publication)
				  LEFT JOIN '._DB_PREFIX_.'press_image pi ON p.id_press_publication = pi.id_press_publication AND pi.default = 1 '; 
				  
		if(!is_null($product_id))
			$query .= ' INNER JOIN '._DB_PREFIX_.'press_products pp ON pp.`id_press_publication` = p.`id_press_publication` AND  pp.`id_product` = '.$product_id;
		
		if(!is_null($category_id))
			$query .= ' INNER JOIN '._DB_PREFIX_.'press_categories pc ON pc.id_press_publication = p.id_press_publication AND pc.id_press_category = '.$category_id;

		$query .= ' WHERE pl.id_lang = '.intval($id_lang);
		
		if($checkEmpty) $query .= ' AND pl.`title` != ""';
		if($publish) $query .= ' AND p.status = "published" AND NOW() >= p.date_on';
		
		if(!is_null($except_id) && is_numeric($except_id))
			$query .= ' AND p.id_press_publication != '.$except_id;
		
		$query .= ' ORDER BY p.date_on DESC, p.id_press_publication DESC ';
		
		if(!is_null($limit)) $query .= ' LIMIT '.$start.','.$limit;

		$result = Db::getInstance()->ExecuteS($query);
		return $result;
	}
	
	public static function nbPrestapress($id_lang = _PS_LANG_DEFAULT_,$publish = false, $category_id = null, $product_id = null, $except_id = null, $checkEmpty = false)
	{
		$query = 'SELECT count(p.id_press_publication) as nb
				  FROM  '._DB_PREFIX_.'press_publication p
				  JOIN '._DB_PREFIX_.'press_publication_lang pl ON (p.id_press_publication = pl.id_press_publication)';
				  
		if(!is_null($category_id))
			$query .= ' INNER JOIN '._DB_PREFIX_.'press_categories pc ON pc.id_press_publication = p.id_press_publication AND pc.id_press_category = '.$category_id;
				  
		if(!is_null($product_id))		  
			$query .= ' INNER JOIN '._DB_PREFIX_.'press_products pp ON pp.`id_press_publication` = p.`id_press_publication` AND  pp.`id_product` = '.$product_id;
		
		$query .= ' WHERE pl.id_lang = '.intval($id_lang);
		
		if(!is_null($except_id) && is_numeric($except_id)) $query .= ' AND p.id_press_publication != '.$except_id;
		
		if($checkEmpty) $query .= ' AND pl.`title` != ""';
	    
		if($publish) $query .= ' AND p.status = "published" AND p.date_on <= NOW()';

		$result = Db::getInstance()->getRow($query);
		if($result)
			return $result['nb'];
		return null;
	}
	
	/***** prestapress images ****/
	
	public function getAllImages($count = false,$exclude_default = false)
	{	
		$select = $count ? "count(*) as nb" : "*";
		$query = 'SELECT '.$select.' FROM  '._DB_PREFIX_.'press_image pi WHERE pi.id_press_publication = '.intval($this->id);
		if($exclude_default) $query .= ' AND pi.default = 0';
			
		$result = Db::getInstance()->ExecuteS($query);
		if($count) return intval($result[0]['nb']);
		return $result;
	}
	
	public function addImage($type,$default = 0)
	{	
		$result = Db::getInstance()->Execute('INSERT INTO '._DB_PREFIX_.'press_image(`id_press_publication`,`type`,`default`) 
												VALUES('.intval($this->id).',"'.$type.'","'.$default.'")');
		if($result) return Db::getInstance()->Insert_ID();
		return $result;
	}
	
	public function setImageDefault($prestapress_image_id){
		if($prestapress_image_id != 0){
			Db::getInstance()->Execute('UPDATE '._DB_PREFIX_.'press_image SET `default` = 0 WHERE id_press_publication = '.intval($this->id));
			Db::getInstance()->Execute('UPDATE '._DB_PREFIX_.'press_image SET `default` = 1 WHERE id_press_image = '.intval($prestapress_image_id));
		}else{
			Db::getInstance()->Execute('UPDATE '._DB_PREFIX_.'press_image SET `default` = 1 WHERE id_press_publication = '.intval($this->id).' ORDER BY id_press_image ASC LIMIT 1');
		}
	}
	
	public function getDefaultImage(){
		$result = Db::getInstance()->getRow('SELECT * FROM  '._DB_PREFIX_.'press_image pi WHERE pi.default = 1 AND pi.id_press_publication = '.intval($this->id));
		return $result;
	}
	
	public function getImage($prestapress_image_id){
		$result = Db::getInstance()->getRow('SELECT * FROM  '._DB_PREFIX_.'press_image pi WHERE pi.id_press_image = '.intval($prestapress_image_id));
		return $result;
	}
	
	public function delImage($prestapress_image_id){
		$result = Db::getInstance()->Execute('DELETE FROM  '._DB_PREFIX_.'press_image WHERE id_press_image = '.intval($prestapress_image_id));
		return $result;
	}
	
	public function cleanImages(){
		$result = Db::getInstance()->Execute('DELETE FROM  '._DB_PREFIX_.'press_image WHERE id_press_publication = '.intval($this->id));
		return $result;
	}
	
	/****** prestapress categories ******/
	
	public function addCategories($groups){
		foreach ($groups as $group){
			$row = array('id_press_publication' => intval($this->id), 'id_press_category' => intval($group));
			Db::getInstance()->AutoExecute(_DB_PREFIX_.'press_categories', $row, 'INSERT');
		}
	}
	
	public function getCategories(){
		$groups = array();
		$result = Db::getInstance()->ExecuteS('
		SELECT pc.`id_press_category` FROM '._DB_PREFIX_.'press_categories pc 
		 WHERE pc.`id_press_publication` = '.intval($this->id));
		foreach ($result as $group)
			$groups[] = $group['id_press_category'];
		return $groups;
	}
	
	public function listCategories($id_lang = _PS_LANG_DEFAULT_, $active = true, $checkEmpty = false){
		
		$query = 'SELECT pc.`id_press_category`, cl.`name`, cl.`link_rewrite` 
					FROM '._DB_PREFIX_.'press_categories pc 
					INNER JOIN '._DB_PREFIX_.'press_category c ON c.`id_press_category` = pc.`id_press_category`
					LEFT JOIN '._DB_PREFIX_.'press_category_lang cl ON cl.`id_press_category` = pc.`id_press_category` AND cl.`id_lang` = '.$id_lang.'
					WHERE pc.`id_press_publication` = '.intval($this->id);
		
		if($active) $query .= ' AND c.`active` = 1 ';
		
		if($checkEmpty) $query .= ' AND cl.`name` != "" '; 
					
		$query .= ' ORDER BY c.position ASC, cl.`name` ASC';
		
		return Db::getInstance()->ExecuteS($query);
	}
	
	public function cleanCategories(){
		Db::getInstance()->Execute('DELETE FROM `'._DB_PREFIX_.'press_categories` WHERE `id_press_publication` = '.intval($this->id));
	}
	
	
	/***** prestapress related *****/
	
	public function cleanRelated(){
		Db::getInstance()->Execute('DELETE FROM `'._DB_PREFIX_.'press_related` WHERE `id_press_publication` = '.intval($this->id));
	}
	
	public function addRelated($groups){
		$i = 1;
		foreach ($groups as $group){
			$row = array('id_press_publication' => intval($this->id), 'id_related_press_publication' => intval($group));
			Db::getInstance()->AutoExecute(_DB_PREFIX_.'press_related', $row, 'INSERT');
			$i++;
		}
	}
	
	public function getRelated(){
		$groups = array();
		$result = Db::getInstance()->ExecuteS('SELECT pr.`id_related_press_publication` 
												FROM '._DB_PREFIX_.'press_related pr 
											 	WHERE pr.`id_press_publication` = '.intval($this->id));
		foreach ($result as $group)
			$groups[] = $group['id_related_press_publication'];
		return $groups;
	}
	
	public function listRelated($id_lang = _PS_LANG_DEFAULT_, $publish = true, $checkEmpty = false){
		
		$query = 'SELECT p.`id_press_publication`, pl.`title`, pl.`link_rewrite` 
				  FROM '._DB_PREFIX_.'press_related pr 
				  INNER JOIN '._DB_PREFIX_.'press_publication p ON p.`id_press_publication` = pr.`id_related_press_publication`
				  LEFT JOIN '._DB_PREFIX_.'press_publication_lang pl ON p.`id_press_publication` = pl.`id_press_publication` AND pl.`id_lang` = '.$id_lang;		
		
		$query .= ' WHERE pr.`id_press_publication` = '.intval($this->id);
		
		if($checkEmpty) $query .= ' AND pl.`title` != "" ';
		
		if($publish)
			$query .= ' AND p.status = "published" AND p.date_on <= NOW()';
					
		$query .= ' ORDER BY p.date_on DESC, p.id_press_publication DESC';
		
		return Db::getInstance()->ExecuteS($query);
	}
	
	/***** prestapress products *****/
	
	public function cleanProducts(){
		Db::getInstance()->Execute('DELETE FROM `'._DB_PREFIX_.'press_products` WHERE `id_press_publication` = '.intval($this->id));
	}
	
	public function addProducts($groups){
		$i = 1;
		foreach ($groups as $group){
			$row = array('id_press_publication' => intval($this->id), 'id_product' => intval($group), 'position' => $i);
			Db::getInstance()->AutoExecute(_DB_PREFIX_.'press_products', $row, 'INSERT');
			$i++;
		}
	}
	
	public function getProductsLite($id_lang = _PS_LANG_DEFAULT_){
		$result = Db::getInstance()->ExecuteS('
			SELECT pp.`id_product`, pl.`name` 
			FROM '._DB_PREFIX_.'press_products pp 
		 	INNER JOIN `'._DB_PREFIX_.'product_lang` pl ON pp.`id_product` = pl.`id_product` AND pl.`id_lang` = '.$id_lang.'
		 WHERE pp.`id_press_publication` = '.intval($this->id).' ORDER BY pp.`position` ASC');
		return $result;
	}
	
	public function getProducts($id_lang = _PS_LANG_DEFAULT_,$active = true){
		
		if(floatval(_PS_VERSION_) < 1.4){
			
			$result = Db::getInstance()->ExecuteS('
				SELECT p.*, pl.`description`, pl.`description_short`, pl.`link_rewrite`, pl.`meta_description`, pl.`meta_keywords`, pl.`meta_title`, pl.`name`, p.`ean13`,
				i.`id_image`, il.`legend`, t.`rate`, cl.`name` AS category_default, DATEDIFF(p.`date_add`, DATE_SUB(NOW(), INTERVAL '.(Validate::isUnsignedInt(Configuration::get('PS_NB_DAYS_NEW_PRODUCT')) ? Configuration::get('PS_NB_DAYS_NEW_PRODUCT') : 20).' DAY)) > 0 AS new
				FROM `'._DB_PREFIX_.'press_products` pp
				LEFT JOIN `'._DB_PREFIX_.'product` p ON p.`id_product` = pp.`id_product`
				LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.intval($id_lang).')
				LEFT JOIN `'._DB_PREFIX_.'category_lang` cl ON (p.`id_category_default` = cl.`id_category` AND cl.`id_lang` = '.intval($id_lang).')		
				LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
				LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.intval($id_lang).')
				LEFT JOIN `'._DB_PREFIX_.'tax` t ON t.`id_tax` = p.`id_tax`
				WHERE pp.`id_press_publication` = '.intval($this->id).' '.($active ? 'AND p.`active` = 1' : ''));

		}else{
			
			$result = Db::getInstance()->ExecuteS('
				SELECT p.*, pl.`description`, pl.`description_short`, pl.`link_rewrite`, pl.`meta_description`, pl.`meta_keywords`, pl.`meta_title`, pl.`name`, p.`ean13`,
				i.`id_image`, il.`legend`, t.`rate`, cl.`name` AS category_default, DATEDIFF(p.`date_add`, DATE_SUB(NOW(), INTERVAL '.(Validate::isUnsignedInt(Configuration::get('PS_NB_DAYS_NEW_PRODUCT')) ? Configuration::get('PS_NB_DAYS_NEW_PRODUCT') : 20).' DAY)) > 0 AS new
				FROM `'._DB_PREFIX_.'press_products` pp
				LEFT JOIN `'._DB_PREFIX_.'product` p ON p.`id_product` = pp.`id_product`
				LEFT JOIN `'._DB_PREFIX_.'product_lang` pl ON (p.`id_product` = pl.`id_product` AND pl.`id_lang` = '.intval($id_lang).')
				LEFT JOIN `'._DB_PREFIX_.'category_lang` cl ON (p.`id_category_default` = cl.`id_category` AND cl.`id_lang` = '.intval($id_lang).')		
				LEFT JOIN `'._DB_PREFIX_.'image` i ON (i.`id_product` = p.`id_product` AND i.`cover` = 1)
				LEFT JOIN `'._DB_PREFIX_.'image_lang` il ON (i.`id_image` = il.`id_image` AND il.`id_lang` = '.intval($id_lang).')				
				LEFT JOIN `'._DB_PREFIX_.'tax_rule` tr ON (p.`id_tax_rules_group` = tr.`id_tax_rules_group`
				                                           AND tr.`id_country` = '.(int)Country::getDefaultCountryId().'
			                                           	   AND tr.`id_state` = 0)
			    LEFT JOIN `'._DB_PREFIX_.'tax` t ON (t.`id_tax` = tr.`id_tax`)
				WHERE pp.`id_press_publication` = '.intval($this->id).' '.($active ? 'AND p.`active` = 1' : ''));
		}
		
		if (!$result) return array();
		return Product::getProductsProperties($id_lang, $result);
	}
	
	public static function dateFormat($format_conf,$date_article){
	 return date($format_conf,strtotime($date_article));
	}
		
	public static function getArticleLink($article_id, $article_rewrite){
		global $cookie;
		
		$rewrite_conf = Prestapress::getRewriteConf();
		
		if($rewrite_conf == true && Configuration::get('PS_REWRITING_SETTINGS')){
			
			$iso = '';
			$countLang = method_exists('Language','countActiveLanguages') ? Language::countActiveLanguages() : count(Language::getLanguages(true));
			if($countLang > 1){
				$iso = Language::getIsoById(intval($cookie->id_lang)).'/';
			}
			
			return _PS_BASE_URL_.__PS_BASE_URI__.$iso.'article/'.$article_id.'-'.$article_rewrite;
		}else{
			return _PS_BASE_URL_.__PS_BASE_URI__.'modules/prestapress/content.php?id='.$article_id;
		}
	}
	
	public static function listLink($p = null){
		global $cookie;
		
		$rewrite_conf = Prestapress::getRewriteConf();
		
		if($rewrite_conf == true && Configuration::get('PS_REWRITING_SETTINGS')){
			
			$iso = '';
			$countLang = method_exists('Language','countActiveLanguages') ? Language::countActiveLanguages() : count(Language::getLanguages(true));
			if($countLang > 1){
				$iso = Language::getIsoById(intval($cookie->id_lang)).'/';
			}
			
			return _PS_BASE_URL_.__PS_BASE_URI__.$iso.'articles'.(!is_null($p) && !empty($p) ? '?p='.$p : '');
		}else{
			return _PS_BASE_URL_.__PS_BASE_URI__.'modules/prestapress/content.php'.(!is_null($p) && !empty($p) ? '?p='.$p : '');
		}
	}
}

?>
