<?php

/**
  * Prestapress module
  *
  * @author AppSide
  * @copyright AppSide
  * @version 1.9
  *
  */
  
class Prestapress extends Module
{	
	private $_html = '';
	
	private static $pref = null;
	
	public static $default_values = array("nb_max_img" => 0,
									"img_width" => 200,
									"img_list_width" => 100,
									"rewrite_active" => 0,
									"category_active" => 1,
									"share_active" => 1,
									"product_active" => 1,
									"related_active" => 1,
									"product_page_related" => 1,
									"front_active" => 1,
									"display_img" => 'list',						
									"view_display_date" => 1,
									"view_display_popin" => 1,
									"list_limit_page" => 5,
									"list_display_date" => 1,
									"file_formats" => "jpg|jpeg|png|gif",
									"img_save_path" => "modules/prestapress/uploads/");
								
	public function __construct()
	{
		$this->name = 'prestapress';
 	 	$this->version = '1.9';
 	 	$this->module_key = "77f48b3e831430e3acdc2a1181d1a8d1";
 	 	
		if(floatval(_PS_VERSION_) >= 1.4){
 	 		$this->tab = 'front_office_features';
 	 	}else{
 	 		$this->tab = 'Prestapress';
 	 	}

		parent::__construct();
		
		if(Tools::getValue('tab') == 'AdminModules' && $this->active) $this->checkServerConf();
		
		$this->displayName = $this->l('Prestapress module');
		$this->description = $this->l('Publication and content module');
	}
	
	public function install()
	{
	 	if(!parent::install()) return false;
		if(!Configuration::updateValue('PRESTAPRESS_CONF',base64_encode(serialize(self::$default_values)))) return false;
		
		$langs = Language::getLanguages();
		
		/**** create tab publications ****/
		$tab1 = new Tab();
		$tab1->class_name = "AdminPrestapress";
		$tab1->module = $this->name;
		$tab1->id_parent = Tab::getCurrentTabId(); 
		foreach($langs as $l){
			$tab1->name[$l['id_lang']] = ucfirst($this->name);
		}
		$tab1->save();
		@copy(dirname(__FILE__)."/AdminPrestapress.gif",_PS_ROOT_DIR_."/img/t/AdminPrestapress.gif");
		
		/**** create tab categories ****/
		$tab2 = new Tab();
		$tab2->class_name = "AdminPrestapressCategory";
		$tab2->module = "prestapress";
		$tab2->id_parent = -1; 
		foreach($langs as $l){
			$tab2->name[$l['id_lang']] = ucfirst($this->name).' categories';
		}
		$tab2->save();
		
		
		/*** RIGHTS MANAGEMENT ***/
		Db::getInstance()->Execute('DELETE FROM '._DB_PREFIX_.'access WHERE `id_tab` = '.(int) $tab1->id.' 
																		 OR `id_tab` = '.(int) $tab2->id);
		
		$profiles = Db::getInstance()->ExecuteS('SELECT `id_profile` FROM '._DB_PREFIX_.'profile');
		if(count($profiles)){
			foreach($profiles as $p){
				
				Db::getInstance()->Execute('INSERT IGNORE INTO `'._DB_PREFIX_.'access`(`id_profile`,`id_tab`,`view`,`add`,`edit`,`delete`) 
																VALUES ('.$p['id_profile'].', '.(int) $tab1->id.',1,1,1,1)');
				
				Db::getInstance()->Execute('INSERT IGNORE INTO `'._DB_PREFIX_.'access`(`id_profile`,`id_tab`,`view`,`add`,`edit`,`delete`) 
																VALUES ('.$p['id_profile'].', '.(int) $tab2->id.',1,1,1,1)');
			}
		}
		
		if(!$this->registerHook('header') OR !$this->registerHook('productTab') OR !$this->registerHook('productTabContent')) return false;
		
		require_once(dirname(__FILE__).'/install-sql.php');
		
		return true;
	}
	
	public function uninstall()
	{		
		/**** delete AdminPrestapressCategory tab ****/
		$tab_id = Tab::getIdFromClassName("AdminPrestapressCategory");
		if($tab_id){
			$tab = new Tab($tab_id);
			$tab->delete();
		}
		/**** delete AdminPrestapress tab ****/
		$tab_id = Tab::getIdFromClassName("AdminPrestapress");
		if($tab_id){
			$tab = new Tab($tab_id);
			$tab->delete();
		}
		@unlink(_PS_ROOT_DIR_."/img/t/AdminPrestapress.gif");
		
		if (!Configuration::deleteByName('PRESTAPRESS_CONF') OR !parent::uninstall()) return false;
		return true;
	}
	
	public function hookHeader($params){
		global $smarty, $cookie, $css_files;
		$css_files[_MODULE_DIR_.$this->name.'/prestapress.css'] = 'screen';
	}
	
	public function hookProductTab($params){
		global $smarty, $cookie, $css_files;
		
		require_once(dirname(__FILE__)."/classes/PspressPublication.php");
		
		$id_product = intval($_GET['id_product']);
		$nb = PspressPublication::nbPrestapress(intval($cookie->id_lang),true,null,$id_product,null,true);
		if($nb > 0) return $this->display(__FILE__, 'prestapress-product-tabtitle.tpl');
	}
	
	public function hookProductTabContent($params){
		global $smarty, $cookie, $css_files;
		
		$id_product = intval($_GET['id_product']);
		if(!$id_product) return false;
		
		require_once(dirname(__FILE__)."/classes/PspressPublication.php");
		
		$pref = self::getPreferences();
		$list = PspressPublication::listPrestapress(intval($cookie->id_lang),true,null,null,null,$id_product,null,true);
		
		if(is_array($list) && count($list) > 0){
			$i = 0;
			foreach($list as $val){
				$list[$i]['link'] = PspressPublication::getArticleLink($val['id_press_publication'],$val['link_rewrite']);
				$i++;
			}
		}
		
		$smarty->assign(array('press_product_list' => $list,'conf' => $pref));
		return $this->display(__FILE__, 'prestapress-product-tabcontent.tpl');	
	}
	
	/** various product page hooks **/
	public function hookExtraLeft($params){ return $this->hookProductTabContent($params); }
	public function hookProductFooter($params){ return $this->hookProductTabContent($params); }
	public function hookExtra($params){ return $this->hookProductTabContent($params); }
	public function hookExtraRight($params){ return $this->hookProductTabContent($params); }
	
	public static function getPreferences(){
		if(is_null(self::$pref)){
			$config = Configuration::get('PRESTAPRESS_CONF');
			$options = self::$default_values;

			if($config) $options = array_merge($options,unserialize(base64_decode($config)));
			self::$pref = $options;
		}
		return self::$pref;
	}
	
	public static function getRewriteConf(){
		self::getPreferences();
		return self::$pref['rewrite_active'];
	}
	
	public function checkServerConf()
	{
		$pref = self::getPreferences();
		$this->warning = '';
		if (!is_writable(_PS_ROOT_DIR_.'/'.$pref['img_save_path'])){
			$this->warning .= _PS_ROOT_DIR_.'/'.$pref['img_save_path'].' '.$this->l('must be writable')."<br />";
		}
		if (!is_writable(_PS_ROOT_DIR_.'/'.$pref['img_save_path'].'cache/')){
			$this->warning .= _PS_ROOT_DIR_.'/'.$pref['img_save_path'].'cache/ '.$this->l('must be writable')."<br />";
		}
	}
	
	private function _postValidation(){
		if (isset($_POST['submitPrestapress']))
		{
			if (empty($_POST['pref']['img_width']) || !is_numeric($_POST['pref']['img_width']))
				$this->_postErrors[] = $this->l('Numeric width is required for image size.');
			
			if (empty($_POST['pref']['list_limit_page']) || !is_numeric($_POST['pref']['list_limit_page']))
				$this->_postErrors[] = $this->l('Number of articles per page must be a number.');
		}
	}
	
	private function _postProcess()
	{
		if (Tools::isSubmit('submitPrestapress'))
		{
			$pref = $_POST['pref'];
			$old_values = self::getPreferences();
			
			$checkboxes = array('category_active','product_active','share_active',
								'list_display_date','view_display_date','related_active',
								'view_display_popin','rewrite_active','product_page_related');
								
			foreach($checkboxes as $input){ if(!isset($pref[$input])) $pref[$input] = 0; }
			
			$new_values = array_merge(self::$default_values,$pref);
			Configuration::updateValue('PRESTAPRESS_CONF',base64_encode(serialize($new_values)));
			
			if(($new_values['product_page_related'] != $old_values['product_page_related']) || ($new_values['product_active'] != $old_values['product_active'])){
				if($new_values['product_page_related'] == 1 && $new_values['product_active'] == 1){
					$this->registerHook('productTab');
					$this->registerHook('productTabContent');
				}else{
					$this->unregisterHook(Hook::get('productTab'));
					$this->unregisterHook(Hook::get('productTabContent'));
				}
			}
		}
		$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('ok').'" /> '.$this->l('Settings updated').'</div>';
	}
	
	private function _displayForm()
	{		
		global $cookie;
		
		$values = !empty($_POST) ? Tools::getValue('pref') : array_merge(self::$default_values,self::getPreferences());
		
		$generatorToken = Tools::getAdminToken('AdminGenerator'.(int)(Tab::getIdFromClassName('AdminGenerator').(int)$cookie->id_employee));
		
		$this->_html .='
			<script type="text/javascript">
		
				$(document).ready(function() { });
				
				function showHide(divid){
					if($("#"+divid).css("display") == "none") $("#"+divid).css("display","block"); 
					else $("#"+divid).css("display","none");
				}
			</script>
		
		<div style="float:right;">
			<div style="float:right;"><a href="#" onclick="showHide(\'slideshow_help\'); return false;"><img src="../img/admin/help.png" alt="'.$this->l('help').'" /></a></div>
			<div class="clear"></div>
			<div id="slideshow_help" style="display:none;">Module d&eacute;velopp&eacute; par <br /><a href="http://www.appside.net" target="_blank">Appside</a></div>
		</div>
		
		<div class="clear"></div>
		
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
		<fieldset>
		<legend>'.$this->l('General').'</legend>
			
		
		<label>'.$this->l('Active categories').'</label>  
		<div class="margin-form">
		<input type="checkbox" name="pref[category_active]" value="1" '.((isset($values['category_active']) && $values['category_active'] == '1') ? 'checked' : '').' />
		</div>
		
		<label>'.$this->l('Active products').'</label>  
		<div class="margin-form">
		<input type="checkbox" name="pref[product_active]" value="1" '.((isset($values['product_active']) && $values['product_active'] == '1') ? 'checked' : '').' />
		</div>
		
		<label>'.$this->l('Enable related articles').'</label>  
		<div class="margin-form">
		<input type="checkbox" name="pref[related_active]" value="1" '.((isset($values['related_active']) && $values['related_active'] == '1') ? 'checked' : '').' />
		</div>
		
		<label>'.$this->l('Active URL Rewriting').'</label>  
		<div class="margin-form">
		<input type="checkbox" name="pref[rewrite_active]" value="1" '.((isset($values['rewrite_active']) && $values['rewrite_active'] == '1') ? 'checked' : '').' />
		</div>
		<div class="clear"></div>
			
		<p class="hint clear" style="display: block; font-size: 11px; width: 830px;">			
			
		&nbsp;&nbsp; RewriteRule ^article(.*) '._MODULE_DIR_.$this->name.'/content.php [QSA,L]<br />
		&nbsp;&nbsp; RewriteRule ^articles(.*) '._MODULE_DIR_.$this->name.'/content.php [QSA,L]
			
			<br />
			<br />
			'.$this->l('If you turn on this feature, you must go to Tools > Generators').'
			  <br /><strong>'.$this->l('Put this above lines in specific configuration field').'</strong> 
			  <br /><a href="?tab=AdminGenerator&token='.$generatorToken.'">'.$this->l('Regenerate a .htaccess file').'</a>
			
			<br /><br />
			<strong>'.$this->l('Or add manually this above line through your current .htaccess file').'</strong><br />
			
		</p>
		
		<div class="clear space"></div>
		
		<label>'.$this->l('Active Addthis').'</label>  
		<div class="margin-form">
		<input type="checkbox" name="pref[share_active]" value="1" '.((isset($values['share_active']) && $values['share_active'] == '1') ? 'checked' : '').' />
		</div>';
		
		$this->_html .= '
			</fieldset>
			<br /><div class="clear"></div>';
		
		$this->_html .= '<fieldset>
							<legend>'.$this->l('List settings').'</legend>
					
						<label>'.$this->l('Number of articles per page').'</label> 
						<div class="margin-form">
						<input type="text" name="pref[list_limit_page]" value="'.$values['list_limit_page'].'" size="3" />
						</div><div class="clear"></div><br />
						
						<label>'.$this->l('Display date').'</label>  
						<div class="margin-form">
						<input type="checkbox" name="pref[list_display_date]" value="1" '.((isset($values['list_display_date']) && $values['list_display_date'] == '1') ? 'checked' : '').'/>
						</div><div class="clear"></div><br />
						
						<label>'.$this->l('Image width in lists').'</label>
						<div class="margin-form">
							<input type="text" name="pref[img_list_width]" value="'.$values['img_list_width'].'" size="3" /> px
						</div>';
		
		$this->_html .= '</fieldset><br /><div class="clear"></div>';
		
		$this->_html .= '<fieldset>
							<legend>'.$this->l('View settings').'</legend>
		
				<label>'.$this->l('Image width in article detail').'</label>
				<div class="margin-form">
					<input type="text" name="pref[img_width]" value="'.$values['img_width'].'" size="3" /> px
				</div><div class="clear"></div><br />
				
				<label>'.$this->l('Images display style').'</label> 
				<div class="margin-form">
					<select name="pref[display_img]">
						<option value="list" '.($values['display_img'] == "list"? "selected" : "").'>'.$this->l('List').' &nbsp;</option>
						<option value="gallery" '.($values['display_img'] == "gallery"? "selected" : "").'>'.$this->l('Gallery').' &nbsp;</option>
					</select>
				</div><div class="clear"></div><br />
				
				<label>'.$this->l('Enable popin for images').'</label>  
					<div class="margin-form">
					<input type="checkbox" name="pref[view_display_popin]" value="1" '.((isset($values['view_display_popin']) && $values['view_display_popin'] == '1') ? 'checked' : '').'/>
				</div>
				
				<div class="clear"></div><br />
				
				<label>'.$this->l('Display date').'</label>  
				<div class="margin-form">
				<input type="checkbox" name="pref[view_display_date]" value="1" '.((isset($values['view_display_date']) && $values['view_display_date'] == '1') ? 'checked' : '').'/>
				</div>
				
				</fieldset>
				<div class="clear"></div><br />';
			
				$this->_html .= '<fieldset>
						<legend>'.$this->l('Product page settings').'</legend>
				
					<label>'.$this->l('Enable related articles in product page').'</label>  
					<div class="margin-form">
					<input type="checkbox" name="pref[product_page_related]" value="1" '.((isset($values['product_page_related']) && $values['product_page_related'] == '1') ? 'checked' : '').'/>
					</div>';
		
		$this->_html .= '</fieldset>';
		
		$this->_html .= '<br /><div class="clear"></div>
						<input class="button" name="submitPrestapress" value="'.$this->l('Update settings').'" type="submit" />';
								
		$this->_html .= '</form>';
	}
	
	public function getContent()
	{
		$this->checkServerConf();
		if($this->warning != ''){
			$this->_html .= '<div style="width:680px;" class="warning bold">'.$this->warning.'</div>';
		}
		
		$this->_html .= '<h2>'.$this->l('Prestapress settings').'</h2>';
		
		$this->_html .= '<p>'.$this->l('If you want to add articles, you must go to the prestapress sub tab on the navigation menu').'</p>';
		if (isset($_POST) && !empty($_POST))
		{
			$this->_postValidation();
			if (!isset($this->_postErrors) || !sizeof($this->_postErrors)){
				$this->_postProcess();
			}else{
				foreach ($this->_postErrors AS $err)
					$this->_html .= '<div class="alert error">'. $err .'</div>';
			}
		}else{
			$this->_html .= '<br />';
		}
		$this->_displayForm();
		return $this->_html;
	}
	
}